@@ -1,25 +1,25 @@
 #' Compare two overlapping correlations based on dependent groups
 #'
-#' Performs a test of significance for the difference between two correlations based on dependent groups (e.g., the same group). The two correlations are overlapping, i.e., they have one variable in common. The comparison is made between \code{r.jk} and \code{r.jh}. The function tests whether the correlations between \code{j} and \code{k} (\code{r.jk}) and between \code{j} and \code{h} (\code{r.jh}) differ in magnitude. Because the significance depends on the intercorrelation between \code{k} and \code{h} (r.kh), this intercorrelation has to be provided as an additional parameter.
+#' Performs a test of significance for the difference between two correlations based on dependent groups (e.g., the same group). The two correlations are overlapping, i.e., they have one variable in common. The comparison is made between \code{r.jk} and \code{r.jh}. The function tests whether the correlations between \code{j} and \code{k} (\code{r.jk}) and between \code{j} and \code{h} (\code{r.jh}) differ in magnitude. Because the significance depends on the intercorrelation between \code{k} and \code{h} (r.kh), this intercorrelation has to be provided as an additional parameter. The function expects correlation coefficients as input.
 #'
-#'@section Methods:
+#'@section Tests:
 #' In the following, \eqn{r_{jk}} and \eqn{r_{jh}} are the two correlations that are being compared; \eqn{Z_{jk}} and \eqn{Z_{jh}} are their \eqn{Z} transformed equivalents.
 #' \eqn{r_{kh}} is the related correlation that is additionally required.
 #' \eqn{n} specifies the size of the group the two correlations are based on.
-#' Some methods make use of Fisher's \eqn{r}-to-\eqn{Z} transformation (1921, p. 26):
+#' Some tests make use of Fisher's \eqn{r}-to-\eqn{Z} transformation (1921, p. 26):
 #'
-#' \deqn{Z = \frac{1}{2}(ln(1+r) - ln(1-r)).}
+#' \deqn{Z = \frac{1}{2}(ln(1+r) - ln(1-r)).}{Z = (1/2)(ln(1+r) - ln(1-r)).}
 #'
 #'\describe{
 ### pearson1898
 #'\item{pearson1898:}{
 #'\emph{Pearson and Filon's (1898) z}
 #'
-#' This method was proposed by Pearson and Filon (1898, p. 259, formula xxxvii).
+#' This test was proposed by Pearson and Filon (1898, p. 259, formula xxxvii).
 #' The test statistic \eqn{z} is computed as
-#' \deqn{z = \frac{\sqrt{n} (r_{jk} - r_{jh})}{\sqrt{(1 - r_{jk}^2)^2 + (1 - r_{jh}^2)^2 - 2k}}}
+#' \deqn{z = \frac{\sqrt{n} (r_{jk} - r_{jh})}{\sqrt{(1 - r_{jk}^2)^2 + (1 - r_{jh}^2)^2 - 2k}}}{z = (\sqrt(n) (r_{jk} - r_{jh}))/(\sqrt((1 - r_{jk}^2)^2 + (1 - r_{jh}^2)^2 - 2k))}
 #' (Steiger, 1980, p. 246, formula 4), where
-#' \deqn{k = r_{kh}(1 - r_{jk}^2 - r_{jh}^2) - \frac{1}{2}(r_{jk}r_{jh})(1 - r_{jk}^2 - r_{jh}^2 - r_{kh}^2)}
+#' \deqn{k = r_{kh}(1 - r_{jk}^2 - r_{jh}^2) - \frac{1}{2}(r_{jk}r_{jh})(1 - r_{jk}^2 - r_{jh}^2 - r_{kh}^2)}{k = r_{kh}(1 - r_{jk}^2 - r_{jh}^2) - (1/2)(r_{jk}r_{jh})(1 - r_{jk}^2 - r_{jh}^2 - r_{kh}^2)}
 #' (Steiger, 1980, p. 245 formula 3).
 #' }
 #'
@@ -28,7 +28,7 @@
 #'\emph{Hotelling's (1940) t}
 #'
 #' The test statistic \eqn{t} is given by
-#' \deqn{t = \frac{(r_{jk} - r_{jh})\sqrt{(n - 3)(1 + r_{kh})}}{\sqrt{2|R|}}}
+#' \deqn{t = \frac{(r_{jk} - r_{jh})\sqrt{(n - 3)(1 + r_{kh})}}{\sqrt{2|R|}}}{t = ((r_{jk} - r_{jh})\sqrt((n - 3)(1 + r_{kh})))/(\sqrt(2|R|))}
 #' (Hotelling, 1940, p. 278, formula 7) with \eqn{df = n - 3}, where
 #' \deqn{|R| = 1 + 2 r_{jk} r_{jh} r_{kh} - r_{jk}^2 - r_{jh}^2 - r_{kh}^2}
 #' (Hotelling, 1940, p. 278).
@@ -39,12 +39,12 @@
 #'\item{williams1959:}{
 #'\emph{Williams' (1959) t}
 #'
-#' This method is a modification of Hotelling's (1940) \eqn{t} and was suggested by Williams (1959).
+#' This test is a modification of Hotelling's (1940) \eqn{t} and was suggested by Williams (1959).
 #' Two mathematically different formulae for Williams' \eqn{t} can be found in the literature (Hittner et al., 2003, p. 152).
 #' This is the version that Hittner et al. (2003, p. 152) labeled as "standard Williams' \eqn{t}":
-#' \deqn{t = (r_{jk} - r_{jh})\sqrt{\frac{(n - 1)(1 + r_{kh})}{2(\frac{n - 1}{n - 3})|R|+\bar r^2(1 - r_{kh})^3}}}
+#' \deqn{t = (r_{jk} - r_{jh})\sqrt{\frac{(n - 1)(1 + r_{kh})}{2(\frac{n - 1}{n - 3})|R|+\bar r^2(1 - r_{kh})^3}}}{t = (r_{jk} - r_{jh})\sqrt(((n - 1)(1 + r_{kh}))/(2((n - 1)/(n - 3))|R|+\bar{r}^2(1 - r_{kh})^3))}
 #' with \eqn{df = n - 3}, where
-#' \deqn{\bar r = \frac{r_{jk} + r_{jh}}{2}}
+#' \deqn{\bar r = \frac{r_{jk} + r_{jh}}{2}}{\bar{r} = (r_{jk} + r_{jh})/2}
 #' and
 #' \deqn{|R| = 1 + 2 r_{jk} r_{jh} r_{kh} - r_{jk}^2 - r_{jh}^2 - r_{kh}^2.}
 #' An alternative formula for Williams' \eqn{t}---termed as "Williams' modified \eqn{t} per Hendrickson, Stanley, and Hills (1970)" by Hittner et al. (2003, p. 152)---is implemented in this function as \code{hendrickson1970} (see below).
@@ -67,17 +67,17 @@
 #' This function implements the corrected formula without the decrement.
 #' The formula implemented in this function is used by Glass and Stanley (1970, p. 313, formula 14.19), Hittner et al. (2003, p. 152), and May and Hittner (1997a, p. 259; 1997b, p. 480):
 #' 
-#' \deqn{z = \frac{(r_{jk} - r_{jh})\sqrt{n}}{\sqrt{(1 - r_{jk}^2)^2 + (1 - r_{jh}^2)^2 - 2 r_{kh}^3 - (2 r_{kh} - r_{jk} r_{jh}) (1 - r_{kh}^2 - r_{jk}^2 - r_{jh}^2)}}.}
+#' \deqn{z = \frac{(r_{jk} - r_{jh})\sqrt{n}}{\sqrt{(1 - r_{jk}^2)^2 + (1 - r_{jh}^2)^2 - 2 r_{kh}^3 - (2 r_{kh} - r_{jk} r_{jh}) (1 - r_{kh}^2 - r_{jk}^2 - r_{jh}^2)}}.}{z = ((r_{jk} - r_{jh})\sqrt(n))/(\sqrt((1 - r_{jk}^2)^2 + (1 - r_{jh}^2)^2 - 2 r_{kh}^3 - (2 r_{kh} - r_{jk} r_{jh}) (1 - r_{kh}^2 - r_{jk}^2 - r_{jh}^2))).}
 #'}
 #'
 ### dunn1969
 #'\item{dunn1969:}{
 #'\emph{Dunn and Clark's (1969) z}
 #' 
-#' The test statistic \eqn{z} of this method is calculated as
-#' \deqn{z = \frac{(Z_{jk} - Z_{jh})\sqrt{n - 3}}{\sqrt{2 - 2c}}}
+#' The test statistic \eqn{z} of this test is calculated as
+#' \deqn{z = \frac{(Z_{jk} - Z_{jh})\sqrt{n - 3}}{\sqrt{2 - 2c}}}{z = ((Z_{jk} - Z_{jh})\sqrt(n - 3))/(\sqrt(2 - 2c))}
 #' (Dunn and Clark, 1969, p. 370, formula 15), where
-#' \deqn{c = \frac{r_{kh}(1 - r_{jk}^2 - r_{jh}^2) - \frac{1}{2} r_{jk} r_{jh} (1 - r_{jk}^2 - r_{jh}^2 - r_{kh}^2)}{(1 - r_{jk}^2)(1 - r_{jh}^2)}}
+#' \deqn{c = \frac{r_{kh}(1 - r_{jk}^2 - r_{jh}^2) - \frac{1}{2} r_{jk} r_{jh} (1 - r_{jk}^2 - r_{jh}^2 - r_{kh}^2)}{(1 - r_{jk}^2)(1 - r_{jh}^2)}}{c = (r_{kh}(1 - r_{jk}^2 - r_{jh}^2) - (1/2) r_{jk} r_{jh} (1 - r_{jk}^2 - r_{jh}^2 - r_{kh}^2))/((1 - r_{jk}^2)(1 - r_{jh}^2))}
 #' (Dunn and Clark, 1969, p. 368, formula 8).
 #'}
 #'
@@ -85,12 +85,12 @@
 #'\item{hendrickson1970:}{
 #'\emph{Hendrickson, Stanley, and Hills' (1970) modification of Williams' (1959) t}
 #'
-#' This method is a modification of Hotelling's (1940) \eqn{t} and was suggested by Williams (1959).
+#' This test is a modification of Hotelling's (1940) \eqn{t} and was suggested by Williams (1959).
 #' Two mathematically different formulae of Williams' (1959) \eqn{t} can be found in the literature.
 #' \code{hendrickson1970} is the version that Hittner et al. (2003, p. 152) labeled as "Williams' modified \eqn{t} per Hendrickson, Stanley, and Hills (1970)".
 #' An alternative formula termed as "standard Williams' \eqn{t}" by Hittner et al. (2003, p. 152) is implemented as \code{williams1959} (see above).
 #' The \code{hendrickson1970} formula can be found in Hendrickson, Stanley, and Hills (1970, p. 193), May and Hittner (1997a, p. 259; 1997b, p. 480), and Hittner et al. (2003, p. 152):
-#' \deqn{t = \frac{(r_{jk} - r_{jh})\sqrt{(n - 3)(1 + r_{kh})}}{\sqrt{2|R|+\frac{(r_{jk} - r_{jh})^2(1 - r_{kh})^3}{4(n - 1)}}}}
+#' \deqn{t = \frac{(r_{jk} - r_{jh})\sqrt{(n - 3)(1 + r_{kh})}}{\sqrt{2|R|+\frac{(r_{jk} - r_{jh})^2(1 - r_{kh})^3}{4(n - 1)}}}}{t = ((r_{jk} - r_{jh})\sqrt((n - 3)(1 + r_{kh})))/(\sqrt(2|R|+\((r_{jk} - r_{jh})^2(1 - r_{kh})^3)/(4(n - 1))))}
 #' with \eqn{df = n - 3}.
 #' A slightly changed version of this formula was provided by Dunn and Clark (1971, p. 905, formula 1.2), but seems to be erroneous, due to an error in the denominator.
 #'}
@@ -99,15 +99,15 @@
 #'\item{steiger1980:}{
 #'\emph{Steiger's (1980) modification of Dunn and Clark's (1969) z using average correlations}
 #'
-#' This method was proposed by Steiger (1980) and is a modification of Dunn and Clark's (1969) \eqn{z}.
+#' This test was proposed by Steiger (1980) and is a modification of Dunn and Clark's (1969) \eqn{z}.
 #' Instead of \eqn{r_{jk}} and \eqn{r_{jh}}, the mean of the two is used.
 #' The test statistic \eqn{z} is defined as
-#' \deqn{z = \frac{(Z_{jk} - Z_{jh})\sqrt{n - 3}}{\sqrt{2 - 2c}}}
+#' \deqn{z = \frac{(Z_{jk} - Z_{jh})\sqrt{n - 3}}{\sqrt{2 - 2c}}}{z = ((Z_{jk} - Z_{jh})\sqrt(n - 3))/(\sqrt(2 - 2c))}
 #' (Steiger 1980, p. 247, formula 14), where
-#' \deqn{\bar r = \frac{r_{jk} + r_{jh}}{2}}
+#' \deqn{\bar r = \frac{r_{jk} + r_{jh}}{2}}{\bar{r} = (r_{jk} + r_{jh})/2}
 #' (Steiger, 1980, p. 247)
 #' and
-#' \deqn{c = \frac{r_{kh}(1 - 2\bar r^2) - \frac{1}{2}\bar r^2(1 - 2\bar r^2 - r_{kh}^2)}{(1 - \bar r^2)^2}}
+#' \deqn{c = \frac{r_{kh}(1 - 2\bar r^2) - \frac{1}{2}\bar r^2(1 - 2\bar r^2 - r_{kh}^2)}{(1 - \bar r^2)^2}}{c = (r_{kh}(1 - 2\bar{r}^2) - (1/2)\bar{r}^2(1 - 2\bar{r}^2 - r_{kh}^2))/((1 - \bar{r}^2)^2)}
 #' (Steiger ,1980, p. 247, formula 10; in the original article, there are brackets missing around the divisor).
 #'}
 #'
@@ -115,17 +115,17 @@
 #'\item{meng1992:}{
 #'\emph{Meng, Rosenthal, and Rubin's (1992) z}
 #'
-#' This method is based on the test statistic \eqn{z},
-#' \deqn{z = (Z_{jk} - Z_{jh}) \sqrt{\frac{n - 3}{2(1 - r_{kh})h}},}
+#' This test is based on the test statistic \eqn{z},
+#' \deqn{z = (Z_{jk} - Z_{jh}) \sqrt{\frac{n - 3}{2(1 - r_{kh})h}},}{z = (Z_{jk} - Z_{jh}) \sqrt((n - 3)/(2(1 - r_{kh})h),}
 #' (Meng et al., 1992, p. 173, formula 1), where
-#' \deqn{h = \frac{1 - f\overline {r^2}}{1 - \overline {r^2}}}
+#' \deqn{h = \frac{1 - f\overline{r^2}}{1 - \overline{r^2}}}{h = (1 - f\overline{r^2})/(1 - \overline{r^2})}
 #' (Meng et al., 1992, p. 173, formula 2),
-#' \deqn{f = \frac{1 - r_{kh}}{2(1 - \overline {r^2})}}
+#' \deqn{f = \frac{1 - r_{kh}}{2(1 - \overline{r^2})}}{f = (1 - r_{kh})/(2(1 - \overline{r^2}))}
 #' (\eqn{f} must be \eqn{\le 1}; Meng et al., 1992, p. 173, formula 3), and
-#' \deqn{\overline {r^2} = \frac{r_{jk}^2 + r_{jh}^2}{2}}
+#' \deqn{\overline{r^2} = \frac{r_{jk}^2 + r_{jh}^2}{2}}{\overline{r^2} = (r_{jk}^2 + r_{jh}^2)/2}
 #' (Meng et al., 1992, p. 173).
-#' This method also provides a confidence interval of the difference between the two correlation coefficients \eqn{r_{jk}} and \eqn{r_{jh}}:
-#' \deqn{L, U = Z_{jk} - Z_{jk} \pm z_{\frac{\alpha}{2}} \sqrt{\frac{2(1 - r_{kh})h}{n - 3}}}
+#' This test also constructs a confidence interval of the difference between the two correlation coefficients \eqn{r_{jk}} and \eqn{r_{jh}}:
+#' \deqn{L, U = Z_{jk} - Z_{jk} \pm z_{\frac{\alpha}{2}} \sqrt{\frac{2(1 - r_{kh})h}{n - 3}}}{L, U = Z_{jk} - Z_{jk} +- z_{\alpha/2} \sqrt((2(1 - r_{kh})h)/(n - 3))}
 #' (Meng et al., 1992, p. 173, formula 4).
 #' \eqn{\alpha} denotes the desired alpha level of the confidence interval.
 #' If the confidence interval includes zero, the null hypothesis that the two correlations are equal must be retained.
@@ -137,15 +137,15 @@
 #'\emph{Hittner, May, and Silver's (2003) modification of Dunn and Clark's (1969) z using a backtransformed average Fisher's (1921) Z procedure}
 #'
 #' The approach to backtransform averaged Fisher's (1921) \eqn{Z}s was first proposed by Silver and Dunlap (1987) and was applied to the comparison of overlapping correlations by Hittner et al. (2003).
-#' The method is based on Steiger's (1980) approach.
+#' The test is based on Steiger's (1980) approach.
 #' The test statistic \eqn{z} is calculated as
-#' \deqn{z = \frac{(Z_{jk} - Z_{jh})\sqrt{n - 3}}{\sqrt{2 - 2c}}}
+#' \deqn{z = \frac{(Z_{jk} - Z_{jh})\sqrt{n - 3}}{\sqrt{2 - 2c}}}{z = ((Z_{jk} - Z_{jh})\sqrt(n - 3))/(\sqrt(2 - 2c))}
 #' (Hittner et al., 2003, p. 153), where
-#' \deqn{c = \frac{r_{kh}(1 - 2\bar r_z^2) - \frac{1}{2}\bar r_z^2(1 - 2\bar r_z^2 - r_{kh}^2)}{(1 - \bar r_z^2)^2}}
+#' \deqn{c = \frac{r_{kh}(1 - 2\bar r_z^2) - \frac{1}{2}\bar r_z^2(1 - 2\bar r_z^2 - r_{kh}^2)}{(1 - \bar r_z^2)^2}}{c = (r_{kh}(1 - 2\bar{r}_z^2) - (1/2)\bar{r}_z^2(1 - 2\bar{r}_z^2 - r_{kh}^2))/((1 - \bar{r}_z^2)^2)}
 #' (Hittner et al., 2003, p. 153),
-#' \deqn{\bar r_z = \frac{exp(2\bar Z - 1)}{exp(2\bar Z + 1)}}
+#' \deqn{\bar r_z = \frac{exp(2\bar Z - 1)}{exp(2\bar Z + 1)}}{\bar{r}_z = (exp(2\bar{Z} - 1))/(exp(2\bar{Z} + 1))}
 #' (Silver and Dunlap, 1987, p. 146, formula 4), and
-#' \deqn{\bar Z = \frac{Z_{jk} + Z_{jh}}{2}}
+#' \deqn{\bar Z = \frac{Z_{jk} + Z_{jh}}{2}}{\bar{Z} = (Z_{jk} + Z_{jh})/2}
 #' (Silver and Dunlap, 1987, p. 146).
 #'}
 #'
@@ -153,20 +153,20 @@
 #'\item{zou2007:}{
 #'\emph{Zou's (2007) confidence interval}
 #'
-#' This method calculates the confidence interval of the difference between the two correlation coefficients \eqn{r_{jk}} and \eqn{r_{jh}}.
+#' This test calculates the confidence interval of the difference between the two correlation coefficients \eqn{r_{jk}} and \eqn{r_{jh}}.
 #' If the confidence interval includes zero, the null hypothesis that the two correlations are equal must be retained.
-#' If zero is outside the confidence interval, the null hypothesis can be rejected.
+#' If the confidence interval does not include zero, the null hypothesis has to be rejected.
 #' A lower and upper bound for the interval (\eqn{L} and \eqn{U}, respectively) is given by
-#' \deqn{L = r_{jk} - r_{jh} - \sqrt{(r_{jk} - l_1)^2 + (u_2 - r_{jh})^2 - 2c(r_{jk} - l_1)(u_2 - r_{jh})}}
+#' \deqn{L = r_{jk} - r_{jh} - \sqrt{(r_{jk} - l_1)^2 + (u_2 - r_{jh})^2 - 2c(r_{jk} - l_1)(u_2 - r_{jh})}}{L = r_{jk} - r_{jh} - \sqrt((r_{jk} - l_1)^2 + (u_2 - r_{jh})^2 - 2c(r_{jk} - l_1)(u_2 - r_{jh}))}
 #' and
-#' \deqn{U = r_{jk} - r_{jh} - \sqrt{(u_1 - r_{jk})^2 + (r_{jh} - l_2)^2 - 2c(u_1 - r_{jk})(r_{jh} - l_2)}}
+#' \deqn{U = r_{jk} - r_{jh} - \sqrt{(u_1 - r_{jk})^2 + (r_{jh} - l_2)^2 - 2c(u_1 - r_{jk})(r_{jh} - l_2)}}{U = r_{jk} - r_{jh} - \sqrt((u_1 - r_{jk})^2 + (r_{jh} - l_2)^2 - 2c(u_1 - r_{jk})(r_{jh} - l_2))}
 #' (Zou, 2007, p. 409), where
-#' \deqn{l = \frac{exp(2l') - 1}{exp(2l') + 1},}
-#' \deqn{u = \frac{exp(2u') - 1}{exp(2u') + 1}}
+#' \deqn{l = \frac{exp(2l') - 1}{exp(2l') + 1},}{l = (exp(2l') - 1)/(exp(2l') + 1),}
+#' \deqn{u = \frac{exp(2u') - 1}{exp(2u') + 1}}{u = (exp(2u') - 1)/(exp(2u') + 1)}
 #' (Zou, 2007, p. 406),
-#' \deqn{c = \frac{(r_{kh} - \frac{1}{2} r_{jk} r_{jh})(1 - r_{jk}^2- r_{jh}^2- r_{kh}^2) + r_{kh}^3}{(1 - r_{jk}^2)(1 - r_{jh}^2)}}
+#' \deqn{c = \frac{(r_{kh} - \frac{1}{2} r_{jk} r_{jh})(1 - r_{jk}^2- r_{jh}^2- r_{kh}^2) + r_{kh}^3}{(1 - r_{jk}^2)(1 - r_{jh}^2)}}{c = ((r_{kh} - (1/2) r_{jk} r_{jh})(1 - r_{jk}^2- r_{jh}^2- r_{kh}^2) + r_{kh}^3)/((1 - r_{jk}^2)(1 - r_{jh}^2))}
 #' (Zou, 2007, p. 409), and
-#' \deqn{l',u' = Z \pm z_{\frac{\alpha}{2}} \sqrt{\frac{1}{n - 3}}}
+#' \deqn{l',u' = Z \pm z_{\frac{\alpha}{2}} \sqrt{\frac{1}{n - 3}}}{l',u' = Z +- z_{\alpha/2} \sqrt(1/(n - 3))}
 #' (Zou, 2007, p. 406).
 #' \eqn{\alpha} denotes the desired alpha level of the confidence interval.
 #'}
@@ -178,22 +178,31 @@
 #' @param r.kh A number specifying the correlation between \eqn{k} and \eqn{h}
 #' @param n An integer defining the size of the group
 #' @param alternative A character string specifying whether the alternative hypothesis is two-sided ("\code{two.sided}"; default) or one-sided ( "\code{greater}" or "\code{less}", depending on the direction). Optionally, the initial letter of the character strings ("\code{t}", "\code{g}", and "\code{l})" can be used.
-#' @param method A vector of character strings specifying the methods to be used (\code{pearson1898}, \code{hotelling1940}, \code{hendrickson1970}, \code{williams1959}, \code{olkin1967}, \code{dunn1969}, \code{steiger1980}, \code{meng1992}, \code{hittner2003}, or \code{zou2007}). Use \code{all} to apply all methods (default). For further information see the method section below.
-#' @param alpha A number defining the alpha level for the hypothesis test. If method \code{meng1992} or \code{zou2007} is used, \eqn{1 - alpha} is taken as the level of confidence for the confidence interval. The default value is \eqn{.05}.
+#' @param test A vector of character strings specifying the tests to be used (\code{pearson1898}, \code{hotelling1940}, \code{hendrickson1970}, \code{williams1959}, \code{olkin1967}, \code{dunn1969}, \code{steiger1980}, \code{meng1992}, \code{hittner2003}, or \code{zou2007}). Use \code{all} to apply all tests (default). For further information see the tests section below.
+#' @param alpha A number defining the alpha level for the hypothesis test. The default value is \eqn{.05}.
+#' @param conf.level A number defining the level of confidence for the confidence interval (if test \code{meng1992} or \code{zou2007} is used). The default value is \eqn{.95}.
+#' @param null.value A number defining the hypothesized difference between the two correlations used for testing the null hypothesis. The default value is \eqn{0}. If the value is other than \eqn{0}, only the test \code{zou2007} that uses a confidence interval is available.
+#' @param data.name A character string giving the name(s) of the data. If \code{data.name} is \code{NULL}, the data names of \code{r.jk}, \code{r.jh}, and \code{r.kh} are used.
+#' @param var.labels A vector of 3 character strings specifying the labels for j, k, and h (in this order).
+#' @param return.htest A logical indicating whether the result should be returned as a list containing a list of class 'htest' for each test. The default value is \code{FALSE}.
 #'
-#' @return Returns an object of the class "\code{cocor.dep.groups.overlap}" with the following slots holding the input parameters described above:
+#' @return Returns an object of the class 'cocor.dep.groups.overlap' with the following slots holding the input parameters described above:
 #' \item{r.jk}{Input parameter}
 #' \item{r.jh}{Input parameter}
 #' \item{r.kh}{Input parameter}
 #' \item{n}{Input parameter}
 #' \item{alternative}{Input parameter}
 #' \item{alpha}{Input parameter}
-#' For each method a slot of the same name exists with a list containing the following elements:
-#' \item{statistic}{The value of the test statistic (unless method \code{zou2007} is used)}
-#' \item{distribution}{The distribution of the test statistic (unless method \code{zou2007} is used)}
-#' \item{df}{The degrees of freedom of the distribution of the test statistic (if method \code{hotelling1940}, \code{hendrickson1970}, or \code{williams1959} is used)}
-#' \item{p.value}{The p-value of the test (unless method \code{zou2007} is used)}
-#' \item{conf.int}{The confidence interval of the difference between the two correlations (if method \code{meng1992} or \code{zou2007} is used)}
+#' \item{conf.level}{Input parameter}
+#' \item{null.value}{Input parameter}
+#' \item{data.name}{Input parameter}
+#' \item{var.labels}{Input parameter}
+#' For each test a slot of the same name exists with a list containing the following elements:
+#' \item{statistic}{The value of the test statistic (unless test \code{zou2007} is used).}
+#' \item{distribution}{The distribution of the test statistic (unless test \code{zou2007} is used).}
+#' \item{df}{The degrees of freedom of the distribution of the test statistic (if test \code{hotelling1940}, \code{hendrickson1970}, or \code{williams1959} is used).}
+#' \item{p.value}{The p-value of the test (unless test \code{zou2007} is used).}
+#' \item{conf.int}{The confidence interval of the difference between the two correlations (if test \code{meng1992} or \code{zou2007} is used).}
 #'
 #' @references
 #' Boyer, I. E., Palachek, A. D., & Schucany. W. R. (1983). An empirical study of related correlation coefficients.  \emph{Journal of Educational Statistics},  \emph{8}, 75-86. doi:10.2307/1164871
@@ -245,9 +254,7 @@
 #' Zou, G. Y. (2007). Toward using confidence intervals to compare correlations. \emph{Psychological Methods}, \emph{12}, 399-413. doi:10.1037/1082-989X.12.4.399
 #'
 #' @seealso
-#' \link{cocor.indep.groups}
-#'
-#' \link{cocor.dep.groups.nonoverlap}
+#' \link{cocor}, \link{cocor.indep.groups}, \link{cocor.dep.groups.nonoverlap}, \link{as.htest}
 #'
 #' @examples
 #' # Compare the difference between the correlations (age, intelligence) and
@@ -257,23 +264,28 @@
 #' r.kh <- .1  # Correlation (intelligence, shoe size)
 #' n <- 315  # Size of the group
 #'
-#' cocor.dep.groups.overlap(r.jk, r.jh, r.kh, n)
+#' cocor.dep.groups.overlap(r.jk, r.jh, r.kh, n, var.labels=c("age", "intelligence", "shoe size"))
 #'
 #' @export
-cocor.dep.groups.overlap <- function(r.jk, r.jh, r.kh, n, alternative="two.sided", method="all", alpha=.05) {
+cocor.dep.groups.overlap <- function(r.jk, r.jh, r.kh, n, alternative="two.sided", test="all", alpha=.05, conf.level=.95, null.value=0, data.name=NULL, var.labels=NULL, return.htest=FALSE) {
   for(x in c("r.jk", "r.jh", "r.kh")) {
-    check.variable(get(x), x)
-    check.variable.range(get(x), x, -1, 1)
+    validate.numeric(get(x), x)
+    validate.numeric.range(get(x), x, -1, 1)
   }
 
-  check.variable(n, "n", "integer")
-  check.variable.range(n, "n", 0, Inf)
+  validate.numeric(n, "n", "integer")
+  validate.numeric.range(n, "n", 0, Inf)
 
-  check.variable(alpha, "alpha")
-  check.variable.range(alpha, "alpha", 0, 1)
-  alternative <- check.alternative(alternative)
+  for(x in c("alpha", "conf.level")) {
+    validate.numeric(get(x), x)
+    validate.numeric.range(get(x), x, 0, 1)
+  }
+  alternative <- validate.alternative(alternative)
 
-  if(any(method == "all")) method <- c("pearson1898", "hotelling1940", "williams1959", "olkin1967", "dunn1969", "hendrickson1970", "steiger1980", "meng1992", "hittner2003", "zou2007")
+  validate.numeric.range(null.value, "null.value", -2, 2)
+
+  if(any(test == "all")) test <- c("pearson1898", "hotelling1940", "williams1959", "olkin1967", "dunn1969", "hendrickson1970", "steiger1980", "meng1992", "hittner2003", "zou2007")
+  test <- validate.test(test, null.value)
 
   result <- new("cocor.dep.groups.overlap",
     r.jk=r.jk,
@@ -281,12 +293,22 @@ cocor.dep.groups.overlap <- function(r.jk, r.jh, r.kh, n, alternative="two.sided
     r.kh=r.kh,
     n=n,
     alternative=alternative,
-    method=method,
-    alpha=alpha
+    test=test,
+    alpha=alpha,
+    conf.level=conf.level,
+    null.value=null.value
   )
+  if(!is.null(data.name)) {
+    validate.character(data.name, "data.name", 1)
+    result@data.name <- data.name
+  }
+  if(!is.null(var.labels)) {
+    validate.character(var.labels, "var.labels", 3)
+    result@var.labels <- var.labels
+  }
 
-  for(m in method) {
-    switch(m,
+  for(x in test) {
+    switch(x,
       pearson1898={
         k <- r.kh * (1 - r.jk^2 - r.jh^2) - 0.5 * r.jk * r.jh * (1 - r.jk^2 - r.jh^2 - r.kh^2)
         z.enum <- sqrt(n) * (r.jk - r.jh)
@@ -369,14 +391,14 @@ cocor.dep.groups.overlap <- function(r.jk, r.jh, r.kh, n, alternative="two.sided
       meng1992={
         r.squared.mean <- (r.jk^2 + r.jh^2) / 2
         f <- (1 - r.kh) / (2 * (1 - r.squared.mean))
-        if(f > 1) f <- 1
+        if(!is.nan(f) && f > 1) f <- 1
         h <- (1 - f * r.squared.mean) / (1 - r.squared.mean)
         z.difference <- fisher.r2z(r.jk) - fisher.r2z(r.jh)
 
         statistic <- z.difference * sqrt((n - 3) / (2 * (1 - r.kh) * h))
         distribution <- "z"
 
-        conf.int.term <- qnorm(alpha/2, lower.tail=FALSE) * sqrt((2 * (1 - r.kh) * h) / (n - 3))
+        conf.int.term <- qnorm((1 - conf.level)/2, lower.tail=FALSE) * sqrt((2 * (1 - r.kh) * h) / (n - 3))
         conf.int <- c(z.difference - conf.int.term, z.difference + conf.int.term)
 
         p.value <- get.p.value(statistic, distribution, alternative)
@@ -395,7 +417,7 @@ cocor.dep.groups.overlap <- function(r.jk, r.jh, r.kh, n, alternative="two.sided
         result@hittner2003 <- list(distribution=distribution, statistic=statistic, p.value=p.value)
       },
       zou2007={
-        x <- qnorm(alpha/2, lower.tail=FALSE) * sqrt(1/(n - 3))
+        x <- qnorm((1 - conf.level)/2, lower.tail=FALSE) * sqrt(1/(n - 3))
 
         c <- ((r.kh - 0.5 * r.jk * r.jh) * (1 - r.jk^2 - r.jh^2 - r.kh^2) + r.kh^3)/((1 - r.jk^2) * (1 - r.jh^2))
 
@@ -411,9 +433,10 @@ cocor.dep.groups.overlap <- function(r.jk, r.jh, r.kh, n, alternative="two.sided
         conf.int <- c(L, U)
         result@zou2007 <- list(conf.int=conf.int)
       },
-      stop(paste("Method '", m, "' not found", sep=""))
+      stop(paste("Test '", x, "' not found", sep=""))
     )
   }
 
+  if(return.htest) return(as.htest(result))
   result
 }
